.. Ax documentation index file, created by
   sphinx-quickstart on Sat Mar  2 00:03:32 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

API Reference
=============

.. toctree::
   :maxdepth: 2

   ax
   benchmark
   core
   exceptions
   metrics
   modelbridge
   models
   plot
   runners
   service
   storage
   telemetry
   utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
